# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Cortex


def test_Cortex_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        computeGCBoundary=dict(argstr="-g",),
        computeWGBoundary=dict(argstr="-w", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        includeAllSubcorticalAreas=dict(argstr="-a", usedefault=True,),
        inputHemisphereLabelFile=dict(argstr="-h %s", extensions=None, mandatory=True,),
        inputTissueFractionFile=dict(argstr="-f %s", extensions=None, mandatory=True,),
        outputCerebrumMask=dict(argstr="-o %s", extensions=None, genfile=True,),
        timer=dict(argstr="--timer",),
        tissueFractionThreshold=dict(argstr="-p %f", usedefault=True,),
        verbosity=dict(argstr="-v %d",),
    )
    inputs = Cortex.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Cortex_outputs():
    output_map = dict(outputCerebrumMask=dict(extensions=None,),)
    outputs = Cortex.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import ApplyWarp


def test_ApplyWarp_inputs():
    input_map = dict(
        abswarp=dict(argstr="--abs", xor=["relwarp"],),
        args=dict(argstr="%s",),
        datatype=dict(argstr="--datatype=%s",),
        environ=dict(nohash=True, usedefault=True,),
        field_file=dict(argstr="--warp=%s", extensions=None,),
        in_file=dict(argstr="--in=%s", extensions=None, mandatory=True, position=0,),
        interp=dict(argstr="--interp=%s", position=-2,),
        mask_file=dict(argstr="--mask=%s", extensions=None,),
        out_file=dict(
            argstr="--out=%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            position=2,
        ),
        output_type=dict(),
        postmat=dict(argstr="--postmat=%s", extensions=None,),
        premat=dict(argstr="--premat=%s", extensions=None,),
        ref_file=dict(argstr="--ref=%s", extensions=None, mandatory=True, position=1,),
        relwarp=dict(argstr="--rel", position=-1, xor=["abswarp"],),
        superlevel=dict(argstr="--superlevel=%s",),
        supersample=dict(argstr="--super",),
    )
    inputs = ApplyWarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ApplyWarp_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ApplyWarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utilities import EMSegmentTransformToNewFormat


def test_EMSegmentTransformToNewFormat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputMRMLFileName=dict(argstr="--inputMRMLFileName %s", extensions=None,),
        outputMRMLFileName=dict(argstr="--outputMRMLFileName %s", hash_files=False,),
        templateFlag=dict(argstr="--templateFlag ",),
    )
    inputs = EMSegmentTransformToNewFormat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EMSegmentTransformToNewFormat_outputs():
    output_map = dict(outputMRMLFileName=dict(extensions=None,),)
    outputs = EMSegmentTransformToNewFormat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fix import Cleaner


def test_Cleaner_inputs():
    input_map = dict(
        aggressive=dict(argstr="-A", position=3,),
        args=dict(argstr="%s",),
        artifacts_list_file=dict(
            argstr="%s", extensions=None, mandatory=True, position=1,
        ),
        cleanup_motion=dict(argstr="-m", position=2,),
        confound_file=dict(argstr="-x %s", extensions=None, position=4,),
        confound_file_1=dict(argstr="-x %s", extensions=None, position=5,),
        confound_file_2=dict(argstr="-x %s", extensions=None, position=6,),
        environ=dict(nohash=True, usedefault=True,),
        highpass=dict(argstr="-m -h %f", position=2, usedefault=True,),
    )
    inputs = Cleaner.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Cleaner_outputs():
    output_map = dict(cleaned_functional_file=dict(extensions=None,),)
    outputs = Cleaner.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MCFLIRT


def test_MCFLIRT_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bins=dict(argstr="-bins %d",),
        cost=dict(argstr="-cost %s",),
        dof=dict(argstr="-dof %d",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-in %s", extensions=None, mandatory=True, position=0,),
        init=dict(argstr="-init %s", extensions=None,),
        interpolation=dict(argstr="-%s_final",),
        mean_vol=dict(argstr="-meanvol",),
        out_file=dict(
            argstr="-out %s", extensions=None, genfile=True, hash_files=False,
        ),
        output_type=dict(),
        ref_file=dict(argstr="-reffile %s", extensions=None,),
        ref_vol=dict(argstr="-refvol %d",),
        rotation=dict(argstr="-rotation %d",),
        save_mats=dict(argstr="-mats",),
        save_plots=dict(argstr="-plots",),
        save_rms=dict(argstr="-rmsabs -rmsrel",),
        scaling=dict(argstr="-scaling %.2f",),
        smooth=dict(argstr="-smooth %.2f",),
        stages=dict(argstr="-stages %d",),
        stats_imgs=dict(argstr="-stats",),
        use_contour=dict(argstr="-edge",),
        use_gradient=dict(argstr="-gdt",),
    )
    inputs = MCFLIRT.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MCFLIRT_outputs():
    output_map = dict(
        mat_file=dict(),
        mean_img=dict(extensions=None,),
        out_file=dict(extensions=None,),
        par_file=dict(extensions=None,),
        rms_files=dict(),
        std_img=dict(extensions=None,),
        variance_img=dict(extensions=None,),
    )
    outputs = MCFLIRT.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import BRAINSTransformConvert


def test_BRAINSTransformConvert_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        displacementVolume=dict(argstr="--displacementVolume %s", hash_files=False,),
        environ=dict(nohash=True, usedefault=True,),
        inputTransform=dict(argstr="--inputTransform %s", extensions=None,),
        outputPrecisionType=dict(argstr="--outputPrecisionType %s",),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
        outputTransformType=dict(argstr="--outputTransformType %s",),
        referenceVolume=dict(argstr="--referenceVolume %s", extensions=None,),
    )
    inputs = BRAINSTransformConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSTransformConvert_outputs():
    output_map = dict(
        displacementVolume=dict(extensions=None,),
        outputTransform=dict(extensions=None,),
    )
    outputs = BRAINSTransformConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..postproc import TrackMerge


def test_TrackMerge_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        output_file=dict(argstr="%s", extensions=None, position=-1, usedefault=True,),
        track_files=dict(argstr="%s...", mandatory=True, position=0,),
    )
    inputs = TrackMerge.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TrackMerge_outputs():
    output_map = dict(track_file=dict(extensions=None,),)
    outputs = TrackMerge.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MRIsExpand


def test_MRIsExpand_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        distance=dict(argstr="%g", mandatory=True, position=-2,),
        dt=dict(argstr="-T %g",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-3,
        ),
        nsurfaces=dict(argstr="-N %d",),
        out_name=dict(argstr="%s", position=-1, usedefault=True,),
        pial=dict(argstr="-pial %s", copyfile=False,),
        smooth_averages=dict(argstr="-A %d",),
        sphere=dict(copyfile=False, usedefault=True,),
        spring=dict(argstr="-S %g",),
        subjects_dir=dict(),
        thickness=dict(argstr="-thickness",),
        thickness_name=dict(argstr="-thickness_name %s", copyfile=False,),
        write_iterations=dict(argstr="-W %d",),
    )
    inputs = MRIsExpand.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRIsExpand_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = MRIsExpand.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import ProbTrackX


def test_ProbTrackX_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        avoid_mp=dict(argstr="--avoid=%s", extensions=None,),
        c_thresh=dict(argstr="--cthr=%.3f",),
        correct_path_distribution=dict(argstr="--pd",),
        dist_thresh=dict(argstr="--distthresh=%.3f",),
        environ=dict(nohash=True, usedefault=True,),
        fibst=dict(argstr="--fibst=%d",),
        force_dir=dict(argstr="--forcedir", usedefault=True,),
        fsamples=dict(mandatory=True,),
        inv_xfm=dict(argstr="--invxfm=%s", extensions=None,),
        loop_check=dict(argstr="--loopcheck",),
        mask=dict(argstr="-m %s", extensions=None, mandatory=True,),
        mask2=dict(argstr="--mask2=%s", extensions=None,),
        mesh=dict(argstr="--mesh=%s", extensions=None,),
        mod_euler=dict(argstr="--modeuler",),
        mode=dict(argstr="--mode=%s", genfile=True,),
        n_samples=dict(argstr="--nsamples=%d", usedefault=True,),
        n_steps=dict(argstr="--nsteps=%d",),
        network=dict(argstr="--network",),
        opd=dict(argstr="--opd", usedefault=True,),
        os2t=dict(argstr="--os2t",),
        out_dir=dict(argstr="--dir=%s", genfile=True,),
        output_type=dict(),
        phsamples=dict(mandatory=True,),
        rand_fib=dict(argstr="--randfib=%d",),
        random_seed=dict(argstr="--rseed",),
        s2tastext=dict(argstr="--s2tastext",),
        sample_random_points=dict(argstr="--sampvox",),
        samples_base_name=dict(argstr="--samples=%s", usedefault=True,),
        seed=dict(argstr="--seed=%s", mandatory=True,),
        seed_ref=dict(argstr="--seedref=%s", extensions=None,),
        step_length=dict(argstr="--steplength=%.3f",),
        stop_mask=dict(argstr="--stop=%s", extensions=None,),
        target_masks=dict(argstr="--targetmasks=%s",),
        thsamples=dict(mandatory=True,),
        use_anisotropy=dict(argstr="--usef",),
        verbose=dict(argstr="--verbose=%d",),
        waypoints=dict(argstr="--waypoints=%s", extensions=None,),
        xfm=dict(argstr="--xfm=%s", extensions=None,),
    )
    inputs = ProbTrackX.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ProbTrackX_outputs():
    output_map = dict(
        fdt_paths=dict(),
        log=dict(extensions=None,),
        particle_files=dict(),
        targets=dict(),
        way_total=dict(extensions=None,),
    )
    outputs = ProbTrackX.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import ShuffleVectorsModule


def test_ShuffleVectorsModule_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVectorFileBaseName=dict(
            argstr="--inputVectorFileBaseName %s", extensions=None,
        ),
        outputVectorFileBaseName=dict(
            argstr="--outputVectorFileBaseName %s", hash_files=False,
        ),
        resampleProportion=dict(argstr="--resampleProportion %f",),
    )
    inputs = ShuffleVectorsModule.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ShuffleVectorsModule_outputs():
    output_map = dict(outputVectorFileBaseName=dict(extensions=None,),)
    outputs = ShuffleVectorsModule.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Copy


def test_Copy_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_copy.mnc",
            position=-1,
        ),
        pixel_values=dict(argstr="-pixel_values", xor=("pixel_values", "real_values"),),
        real_values=dict(argstr="-real_values", xor=("pixel_values", "real_values"),),
    )
    inputs = Copy.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Copy_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Copy.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import Atropos


def test_Atropos_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        convergence_threshold=dict(requires=["n_iterations"],),
        dimension=dict(argstr="--image-dimensionality %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        icm_use_synchronous_update=dict(argstr="%s",),
        initialization=dict(
            argstr="%s", mandatory=True, requires=["number_of_tissue_classes"],
        ),
        intensity_images=dict(argstr="--intensity-image %s...", mandatory=True,),
        kmeans_init_centers=dict(),
        likelihood_model=dict(argstr="--likelihood-model %s",),
        mask_image=dict(argstr="--mask-image %s", extensions=None, mandatory=True,),
        maximum_number_of_icm_terations=dict(requires=["icm_use_synchronous_update"],),
        mrf_radius=dict(requires=["mrf_smoothing_factor"],),
        mrf_smoothing_factor=dict(argstr="%s",),
        n_iterations=dict(argstr="%s",),
        num_threads=dict(nohash=True, usedefault=True,),
        number_of_tissue_classes=dict(mandatory=True,),
        out_classified_image_name=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False,
        ),
        output_posteriors_name_template=dict(usedefault=True,),
        posterior_formulation=dict(argstr="%s",),
        prior_image=dict(),
        prior_probability_threshold=dict(requires=["prior_weighting"],),
        prior_weighting=dict(),
        save_posteriors=dict(),
        use_mixture_model_proportions=dict(requires=["posterior_formulation"],),
        use_random_seed=dict(argstr="--use-random-seed %d", usedefault=True,),
    )
    inputs = Atropos.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Atropos_outputs():
    output_map = dict(classified_image=dict(extensions=None,), posteriors=dict(),)
    outputs = Atropos.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Average


def test_Average_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        avgdim=dict(argstr="-avgdim %s",),
        binarize=dict(argstr="-binarize",),
        binrange=dict(argstr="-binrange %s %s",),
        binvalue=dict(argstr="-binvalue %s",),
        check_dimensions=dict(
            argstr="-check_dimensions", xor=("check_dimensions", "no_check_dimensions"),
        ),
        clobber=dict(argstr="-clobber", usedefault=True,),
        copy_header=dict(argstr="-copy_header", xor=("copy_header", "no_copy_header"),),
        debug=dict(argstr="-debug",),
        environ=dict(nohash=True, usedefault=True,),
        filelist=dict(
            argstr="-filelist %s",
            extensions=None,
            mandatory=True,
            xor=("input_files", "filelist"),
        ),
        format_byte=dict(
            argstr="-byte",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_double=dict(
            argstr="-double",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_filetype=dict(
            argstr="-filetype",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_float=dict(
            argstr="-float",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_int=dict(
            argstr="-int",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_long=dict(
            argstr="-long",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_short=dict(
            argstr="-short",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_signed=dict(
            argstr="-signed",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_unsigned=dict(
            argstr="-unsigned",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        input_files=dict(
            argstr="%s",
            mandatory=True,
            position=-2,
            sep=" ",
            xor=("input_files", "filelist"),
        ),
        max_buffer_size_in_kb=dict(
            argstr="-max_buffer_size_in_kb %d", usedefault=True,
        ),
        no_check_dimensions=dict(
            argstr="-nocheck_dimensions",
            xor=("check_dimensions", "no_check_dimensions"),
        ),
        no_copy_header=dict(
            argstr="-nocopy_header", xor=("copy_header", "no_copy_header"),
        ),
        nonormalize=dict(argstr="-nonormalize", xor=("normalize", "nonormalize"),),
        normalize=dict(argstr="-normalize", xor=("normalize", "nonormalize"),),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_files"],
            name_template="%s_averaged.mnc",
            position=-1,
        ),
        quiet=dict(argstr="-quiet", xor=("verbose", "quiet"),),
        sdfile=dict(argstr="-sdfile %s", extensions=None,),
        two=dict(argstr="-2",),
        verbose=dict(argstr="-verbose", xor=("verbose", "quiet"),),
        voxel_range=dict(argstr="-range %d %d",),
        weights=dict(argstr="-weights %s", sep=",",),
        width_weighted=dict(argstr="-width_weighted", requires=("avgdim",),),
    )
    inputs = Average.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Average_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Average.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Edge3


def test_Edge3_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        datum=dict(argstr="-datum %s",),
        environ=dict(nohash=True, usedefault=True,),
        fscale=dict(argstr="-fscale", xor=["gscale", "nscale", "scale_floats"],),
        gscale=dict(argstr="-gscale", xor=["fscale", "nscale", "scale_floats"],),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=0,
        ),
        nscale=dict(argstr="-nscale", xor=["fscale", "gscale", "scale_floats"],),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr="-prefix %s", extensions=None, position=-1,),
        outputtype=dict(),
        scale_floats=dict(
            argstr="-scale_floats %f", xor=["fscale", "gscale", "nscale"],
        ),
        verbose=dict(argstr="-verbose",),
    )
    inputs = Edge3.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Edge3_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Edge3.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Beast


def test_Beast_inputs():
    input_map = dict(
        abspath=dict(argstr="-abspath", usedefault=True,),
        args=dict(argstr="%s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        confidence_level_alpha=dict(argstr="-alpha %s", usedefault=True,),
        configuration_file=dict(argstr="-configuration %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        fill_holes=dict(argstr="-fill",),
        flip_images=dict(argstr="-flip",),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        library_dir=dict(argstr="%s", mandatory=True, position=-3,),
        load_moments=dict(argstr="-load_moments",),
        median_filter=dict(argstr="-median",),
        nlm_filter=dict(argstr="-nlm_filter",),
        number_selected_images=dict(argstr="-selection_num %s", usedefault=True,),
        output_file=dict(
            argstr="%s",
            extensions=None,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_beast_mask.mnc",
            position=-1,
        ),
        patch_size=dict(argstr="-patch_size %s", usedefault=True,),
        probability_map=dict(argstr="-probability",),
        same_resolution=dict(argstr="-same_resolution",),
        search_area=dict(argstr="-search_area %s", usedefault=True,),
        smoothness_factor_beta=dict(argstr="-beta %s", usedefault=True,),
        threshold_patch_selection=dict(argstr="-threshold %s", usedefault=True,),
        voxel_size=dict(argstr="-voxel_size %s", usedefault=True,),
    )
    inputs = Beast.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Beast_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Beast.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..reg import RegF3D


def test_RegF3D_inputs():
    input_map = dict(
        aff_file=dict(argstr="-aff %s", extensions=None,),
        amc_flag=dict(argstr="-amc",),
        args=dict(argstr="%s",),
        be_val=dict(argstr="-be %f",),
        cpp_file=dict(
            argstr="-cpp %s",
            extensions=None,
            name_source=["flo_file"],
            name_template="%s_cpp.nii.gz",
        ),
        environ=dict(nohash=True, usedefault=True,),
        fbn2_val=dict(argstr="-fbn %d %d",),
        fbn_val=dict(argstr="--fbn %d",),
        flo_file=dict(argstr="-flo %s", extensions=None, mandatory=True,),
        flo_smooth_val=dict(argstr="-smooF %f",),
        flwth2_thr_val=dict(argstr="-fLwTh %d %f",),
        flwth_thr_val=dict(argstr="--fLwTh %f",),
        fmask_file=dict(argstr="-fmask %s", extensions=None,),
        fupth2_thr_val=dict(argstr="-fUpTh %d %f",),
        fupth_thr_val=dict(argstr="--fUpTh %f",),
        incpp_file=dict(argstr="-incpp %s", extensions=None,),
        jl_val=dict(argstr="-jl %f",),
        kld2_flag=dict(argstr="-kld %d",),
        kld_flag=dict(argstr="--kld",),
        le_val=dict(argstr="-le %f",),
        ln_val=dict(argstr="-ln %d",),
        lncc2_val=dict(argstr="-lncc %d %f",),
        lncc_val=dict(argstr="--lncc %f",),
        lp_val=dict(argstr="-lp %d",),
        maxit_val=dict(argstr="-maxit %d",),
        nmi_flag=dict(argstr="--nmi",),
        no_app_jl_flag=dict(argstr="-noAppJL",),
        noconj_flag=dict(argstr="-noConj",),
        nopy_flag=dict(argstr="-nopy",),
        nox_flag=dict(argstr="-nox",),
        noy_flag=dict(argstr="-noy",),
        noz_flag=dict(argstr="-noz",),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        pad_val=dict(argstr="-pad %f",),
        pert_val=dict(argstr="-pert %d",),
        rbn2_val=dict(argstr="-rbn %d %d",),
        rbn_val=dict(argstr="--rbn %d",),
        ref_file=dict(argstr="-ref %s", extensions=None, mandatory=True,),
        ref_smooth_val=dict(argstr="-smooR %f",),
        res_file=dict(
            argstr="-res %s",
            extensions=None,
            name_source=["flo_file"],
            name_template="%s_res.nii.gz",
        ),
        rlwth2_thr_val=dict(argstr="-rLwTh %d %f",),
        rlwth_thr_val=dict(argstr="--rLwTh %f",),
        rmask_file=dict(argstr="-rmask %s", extensions=None,),
        rupth2_thr_val=dict(argstr="-rUpTh %d %f",),
        rupth_thr_val=dict(argstr="--rUpTh %f",),
        smooth_grad_val=dict(argstr="-smoothGrad %f",),
        ssd2_flag=dict(argstr="-ssd %d",),
        ssd_flag=dict(argstr="--ssd",),
        sx_val=dict(argstr="-sx %f",),
        sy_val=dict(argstr="-sy %f",),
        sz_val=dict(argstr="-sz %f",),
        vel_flag=dict(argstr="-vel",),
        verbosity_off_flag=dict(argstr="-voff",),
    )
    inputs = RegF3D.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegF3D_outputs():
    output_map = dict(
        avg_output=dict(),
        cpp_file=dict(extensions=None,),
        invcpp_file=dict(extensions=None,),
        invres_file=dict(extensions=None,),
        res_file=dict(extensions=None,),
    )
    outputs = RegF3D.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import OutlierCount


def test_OutlierCount_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        autoclip=dict(argstr="-autoclip", usedefault=True, xor=["mask"],),
        automask=dict(argstr="-automask", usedefault=True, xor=["mask"],),
        environ=dict(nohash=True, usedefault=True,),
        fraction=dict(argstr="-fraction", usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        interval=dict(argstr="-range", usedefault=True,),
        legendre=dict(argstr="-legendre", usedefault=True,),
        mask=dict(argstr="-mask %s", extensions=None, xor=["autoclip", "automask"],),
        out_file=dict(
            extensions=None,
            keep_extension=False,
            name_source=["in_file"],
            name_template="%s_outliers",
        ),
        outliers_file=dict(
            argstr="-save %s",
            extensions=None,
            keep_extension=True,
            name_source=["in_file"],
            name_template="%s_outliers",
            output_name="out_outliers",
        ),
        polort=dict(argstr="-polort %d",),
        qthr=dict(argstr="-qthr %.5f", usedefault=True,),
        save_outliers=dict(usedefault=True,),
    )
    inputs = OutlierCount.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_OutlierCount_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), out_outliers=dict(extensions=None,),
    )
    outputs = OutlierCount.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import TrackBootstrap


def test_TrackBootstrap_inputs():
    input_map = dict(
        anisfile=dict(argstr="-anisfile %s", extensions=None,),
        anisthresh=dict(argstr="-anisthresh %f",),
        args=dict(argstr="%s",),
        bgmask=dict(argstr="-bgmask %s", extensions=None,),
        bsdatafiles=dict(argstr="-bsdatafile %s", mandatory=True,),
        curveinterval=dict(argstr="-curveinterval %f", requires=["curvethresh"],),
        curvethresh=dict(argstr="-curvethresh %f",),
        data_dims=dict(argstr="-datadims %s", units="voxels",),
        environ=dict(nohash=True, usedefault=True,),
        gzip=dict(argstr="-gzip",),
        in_file=dict(argstr="-inputfile %s", extensions=None, position=1,),
        inputdatatype=dict(argstr="-inputdatatype %s",),
        inputmodel=dict(argstr="-inputmodel %s", usedefault=True,),
        interpolator=dict(argstr="-interpolator %s",),
        inversion=dict(argstr="-inversion %s",),
        ipthresh=dict(argstr="-ipthresh %f",),
        iterations=dict(argstr="-iterations %d", units="NA",),
        maxcomponents=dict(argstr="-maxcomponents %d", units="NA",),
        numpds=dict(argstr="-numpds %d", units="NA",),
        out_file=dict(
            argstr="-outputfile %s", extensions=None, genfile=True, position=-1,
        ),
        output_root=dict(argstr="-outputroot %s", extensions=None, position=-1,),
        outputtracts=dict(argstr="-outputtracts %s",),
        scheme_file=dict(argstr="-schemefile %s", extensions=None, mandatory=True,),
        seed_file=dict(argstr="-seedfile %s", extensions=None, position=2,),
        stepsize=dict(argstr="-stepsize %f", requires=["tracker"],),
        tracker=dict(argstr="-tracker %s", usedefault=True,),
        voxel_dims=dict(argstr="-voxeldims %s", units="mm",),
    )
    inputs = TrackBootstrap.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TrackBootstrap_outputs():
    output_map = dict(tracked=dict(extensions=None,),)
    outputs = TrackBootstrap.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import DenoiseImage


def test_DenoiseImage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="-d %d",),
        environ=dict(nohash=True, usedefault=True,),
        input_image=dict(argstr="-i %s", extensions=None, mandatory=True,),
        noise_image=dict(
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source=["input_image"],
            name_template="%s_noise",
        ),
        noise_model=dict(argstr="-n %s", usedefault=True,),
        num_threads=dict(nohash=True, usedefault=True,),
        output_image=dict(
            argstr="-o %s",
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source=["input_image"],
            name_template="%s_noise_corrected",
        ),
        save_noise=dict(mandatory=True, usedefault=True, xor=["noise_image"],),
        shrink_factor=dict(argstr="-s %s", usedefault=True,),
        verbose=dict(argstr="-v",),
    )
    inputs = DenoiseImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DenoiseImage_outputs():
    output_map = dict(
        noise_image=dict(extensions=None,), output_image=dict(extensions=None,),
    )
    outputs = DenoiseImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..cmtk import ROIGen


def test_ROIGen_inputs():
    input_map = dict(
        LUT_file=dict(extensions=None, xor=["use_freesurfer_LUT"],),
        aparc_aseg_file=dict(extensions=None, mandatory=True,),
        freesurfer_dir=dict(requires=["use_freesurfer_LUT"],),
        out_dict_file=dict(extensions=None, genfile=True,),
        out_roi_file=dict(extensions=None, genfile=True,),
        use_freesurfer_LUT=dict(xor=["LUT_file"],),
    )
    inputs = ROIGen.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ROIGen_outputs():
    output_map = dict(
        dict_file=dict(extensions=None,), roi_file=dict(extensions=None,),
    )
    outputs = ROIGen.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Seg


def test_Seg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bias_classes=dict(argstr="-bias_classes %s",),
        bias_fwhm=dict(argstr="-bias_fwhm %f",),
        blur_meth=dict(argstr="-blur_meth %s",),
        bmrf=dict(argstr="-bmrf %f",),
        classes=dict(argstr="-classes %s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-anat %s",
            copyfile=True,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        main_N=dict(argstr="-main_N %d",),
        mask=dict(argstr="-mask %s", mandatory=True, position=-2,),
        mixfloor=dict(argstr="-mixfloor %f",),
        mixfrac=dict(argstr="-mixfrac %s",),
        prefix=dict(argstr="-prefix %s",),
    )
    inputs = Seg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Seg_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Seg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import AutoTLRC


def test_AutoTLRC_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        base=dict(argstr="-base %s", mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-input %s", copyfile=False, extensions=None, mandatory=True,
        ),
        no_ss=dict(argstr="-no_ss",),
        outputtype=dict(),
    )
    inputs = AutoTLRC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AutoTLRC_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = AutoTLRC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..arithmetic import AddScalarVolumes


def test_AddScalarVolumes_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume1=dict(argstr="%s", extensions=None, position=-3,),
        inputVolume2=dict(argstr="%s", extensions=None, position=-2,),
        order=dict(argstr="--order %s",),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
    )
    inputs = AddScalarVolumes.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AddScalarVolumes_outputs():
    output_map = dict(outputVolume=dict(extensions=None, position=-1,),)
    outputs = AddScalarVolumes.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import TractSkeleton


def test_TractSkeleton_inputs():
    input_map = dict(
        alt_data_file=dict(argstr="-a %s", extensions=None,),
        alt_skeleton=dict(argstr="-s %s", extensions=None,),
        args=dict(argstr="%s",),
        data_file=dict(extensions=None,),
        distance_map=dict(extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True,),
        output_type=dict(),
        project_data=dict(
            argstr="-p %.3f %s %s %s %s",
            requires=["threshold", "distance_map", "data_file"],
        ),
        projected_data=dict(extensions=None,),
        search_mask_file=dict(extensions=None, xor=["use_cingulum_mask"],),
        skeleton_file=dict(argstr="-o %s",),
        threshold=dict(),
        use_cingulum_mask=dict(usedefault=True, xor=["search_mask_file"],),
    )
    inputs = TractSkeleton.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TractSkeleton_outputs():
    output_map = dict(
        projected_data=dict(extensions=None,), skeleton_file=dict(extensions=None,),
    )
    outputs = TractSkeleton.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSMultiSTAPLE


def test_BRAINSMultiSTAPLE_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputCompositeT1Volume=dict(
            argstr="--inputCompositeT1Volume %s", extensions=None,
        ),
        inputLabelVolume=dict(argstr="--inputLabelVolume %s...",),
        inputTransform=dict(argstr="--inputTransform %s...",),
        labelForUndecidedPixels=dict(argstr="--labelForUndecidedPixels %d",),
        outputConfusionMatrix=dict(
            argstr="--outputConfusionMatrix %s", hash_files=False,
        ),
        outputMultiSTAPLE=dict(argstr="--outputMultiSTAPLE %s", hash_files=False,),
        resampledVolumePrefix=dict(argstr="--resampledVolumePrefix %s",),
        skipResampling=dict(argstr="--skipResampling ",),
    )
    inputs = BRAINSMultiSTAPLE.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSMultiSTAPLE_outputs():
    output_map = dict(
        outputConfusionMatrix=dict(extensions=None,),
        outputMultiSTAPLE=dict(extensions=None,),
    )
    outputs = BRAINSMultiSTAPLE.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import AddXFormToHeader


def test_AddXFormToHeader_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        copy_name=dict(argstr="-c",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        out_file=dict(argstr="%s", extensions=None, position=-1, usedefault=True,),
        subjects_dir=dict(),
        transform=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        verbose=dict(argstr="-v",),
    )
    inputs = AddXFormToHeader.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AddXFormToHeader_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = AddXFormToHeader.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import LinRecon


def test_LinRecon_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bgmask=dict(argstr="-bgmask %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        log=dict(argstr="-log",),
        normalize=dict(argstr="-normalize",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        qball_mat=dict(argstr="%s", extensions=None, mandatory=True, position=3,),
        scheme_file=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
    )
    inputs = LinRecon.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_LinRecon_outputs():
    output_map = dict(recon_data=dict(extensions=None,),)
    outputs = LinRecon.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import CurvatureStats


def test_CurvatureStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        copy_inputs=dict(),
        curvfile1=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        curvfile2=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        environ=dict(nohash=True, usedefault=True,),
        hemisphere=dict(argstr="%s", mandatory=True, position=-3,),
        min_max=dict(argstr="-m",),
        out_file=dict(
            argstr="-o %s",
            extensions=None,
            hash_files=False,
            name_source=["hemisphere"],
            name_template="%s.curv.stats",
        ),
        subject_id=dict(argstr="%s", mandatory=True, position=-4, usedefault=True,),
        subjects_dir=dict(),
        surface=dict(argstr="-F %s", extensions=None,),
        values=dict(argstr="-G",),
        write=dict(argstr="--writeCurvatureFiles",),
    )
    inputs = CurvatureStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CurvatureStats_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = CurvatureStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import MedicAlgorithmImageCalculator


def test_MedicAlgorithmImageCalculator_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inOperation=dict(argstr="--inOperation %s",),
        inVolume=dict(argstr="--inVolume %s", extensions=None,),
        inVolume2=dict(argstr="--inVolume2 %s", extensions=None,),
        null=dict(argstr="--null %s",),
        outResult=dict(argstr="--outResult %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = MedicAlgorithmImageCalculator.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MedicAlgorithmImageCalculator_outputs():
    output_map = dict(outResult=dict(extensions=None,),)
    outputs = MedicAlgorithmImageCalculator.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Resample


def test_Resample_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        coronal_slices=dict(
            argstr="-coronal", xor=("transverse", "sagittal", "coronal"),
        ),
        dircos=dict(
            argstr="-dircos %s %s %s", xor=("nelements", "nelements_x_y_or_z"),
        ),
        environ=dict(nohash=True, usedefault=True,),
        fill=dict(argstr="-fill", xor=("nofill", "fill"),),
        fill_value=dict(argstr="-fillvalue %s", requires=["fill"],),
        format_byte=dict(
            argstr="-byte",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_double=dict(
            argstr="-double",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_float=dict(
            argstr="-float",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_int=dict(
            argstr="-int",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_long=dict(
            argstr="-long",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_short=dict(
            argstr="-short",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_signed=dict(
            argstr="-signed",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_unsigned=dict(
            argstr="-unsigned",
            xor=(
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        half_width_sinc_window=dict(
            argstr="-width %s", requires=["sinc_interpolation"],
        ),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        input_grid_files=dict(),
        invert_transformation=dict(argstr="-invert_transformation",),
        keep_real_range=dict(
            argstr="-keep_real_range", xor=("keep_real_range", "nokeep_real_range"),
        ),
        like=dict(argstr="-like %s", extensions=None,),
        nearest_neighbour_interpolation=dict(
            argstr="-nearest_neighbour",
            xor=(
                "trilinear_interpolation",
                "tricubic_interpolation",
                "nearest_neighbour_interpolation",
                "sinc_interpolation",
            ),
        ),
        nelements=dict(
            argstr="-nelements %s %s %s", xor=("nelements", "nelements_x_y_or_z"),
        ),
        no_fill=dict(argstr="-nofill", xor=("nofill", "fill"),),
        no_input_sampling=dict(
            argstr="-use_input_sampling", xor=("vio_transform", "no_input_sampling"),
        ),
        nokeep_real_range=dict(
            argstr="-nokeep_real_range", xor=("keep_real_range", "nokeep_real_range"),
        ),
        origin=dict(argstr="-origin %s %s %s",),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_resample.mnc",
            position=-1,
        ),
        output_range=dict(argstr="-range %s %s",),
        sagittal_slices=dict(
            argstr="-sagittal", xor=("transverse", "sagittal", "coronal"),
        ),
        sinc_interpolation=dict(
            argstr="-sinc",
            xor=(
                "trilinear_interpolation",
                "tricubic_interpolation",
                "nearest_neighbour_interpolation",
                "sinc_interpolation",
            ),
        ),
        sinc_window_hamming=dict(
            argstr="-hamming",
            requires=["sinc_interpolation"],
            xor=("sinc_window_hanning", "sinc_window_hamming"),
        ),
        sinc_window_hanning=dict(
            argstr="-hanning",
            requires=["sinc_interpolation"],
            xor=("sinc_window_hanning", "sinc_window_hamming"),
        ),
        spacetype=dict(argstr="-spacetype %s",),
        standard_sampling=dict(argstr="-standard_sampling",),
        start=dict(argstr="-start %s %s %s", xor=("nelements", "nelements_x_y_or_z"),),
        step=dict(argstr="-step %s %s %s", xor=("nelements", "nelements_x_y_or_z"),),
        talairach=dict(argstr="-talairach",),
        transformation=dict(argstr="-transformation %s", extensions=None,),
        transverse_slices=dict(
            argstr="-transverse", xor=("transverse", "sagittal", "coronal"),
        ),
        tricubic_interpolation=dict(
            argstr="-tricubic",
            xor=(
                "trilinear_interpolation",
                "tricubic_interpolation",
                "nearest_neighbour_interpolation",
                "sinc_interpolation",
            ),
        ),
        trilinear_interpolation=dict(
            argstr="-trilinear",
            xor=(
                "trilinear_interpolation",
                "tricubic_interpolation",
                "nearest_neighbour_interpolation",
                "sinc_interpolation",
            ),
        ),
        two=dict(argstr="-2",),
        units=dict(argstr="-units %s",),
        vio_transform=dict(
            argstr="-tfm_input_sampling", xor=("vio_transform", "no_input_sampling"),
        ),
        xdircos=dict(
            argstr="-xdircos %s",
            requires=("ydircos", "zdircos"),
            xor=("dircos", "dircos_x_y_or_z"),
        ),
        xnelements=dict(
            argstr="-xnelements %s",
            requires=("ynelements", "znelements"),
            xor=("nelements", "nelements_x_y_or_z"),
        ),
        xstart=dict(
            argstr="-xstart %s",
            requires=("ystart", "zstart"),
            xor=("start", "start_x_y_or_z"),
        ),
        xstep=dict(
            argstr="-xstep %s",
            requires=("ystep", "zstep"),
            xor=("step", "step_x_y_or_z"),
        ),
        ydircos=dict(
            argstr="-ydircos %s",
            requires=("xdircos", "zdircos"),
            xor=("dircos", "dircos_x_y_or_z"),
        ),
        ynelements=dict(
            argstr="-ynelements %s",
            requires=("xnelements", "znelements"),
            xor=("nelements", "nelements_x_y_or_z"),
        ),
        ystart=dict(
            argstr="-ystart %s",
            requires=("xstart", "zstart"),
            xor=("start", "start_x_y_or_z"),
        ),
        ystep=dict(
            argstr="-ystep %s",
            requires=("xstep", "zstep"),
            xor=("step", "step_x_y_or_z"),
        ),
        zdircos=dict(
            argstr="-zdircos %s",
            requires=("xdircos", "ydircos"),
            xor=("dircos", "dircos_x_y_or_z"),
        ),
        znelements=dict(
            argstr="-znelements %s",
            requires=("xnelements", "ynelements"),
            xor=("nelements", "nelements_x_y_or_z"),
        ),
        zstart=dict(
            argstr="-zstart %s",
            requires=("xstart", "ystart"),
            xor=("start", "start_x_y_or_z"),
        ),
        zstep=dict(
            argstr="-zstep %s",
            requires=("xstep", "ystep"),
            xor=("step", "step_x_y_or_z"),
        ),
    )
    inputs = Resample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Resample_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Resample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Norm


def test_Norm_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        clamp=dict(argstr="-clamp", usedefault=True,),
        clobber=dict(argstr="-clobber", usedefault=True,),
        cutoff=dict(argstr="-cutoff %s",),
        environ=dict(nohash=True, usedefault=True,),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        lower=dict(argstr="-lower %s",),
        mask=dict(argstr="-mask %s", extensions=None,),
        out_ceil=dict(argstr="-out_ceil %s",),
        out_floor=dict(argstr="-out_floor %s",),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_norm.mnc",
            position=-1,
        ),
        output_threshold_mask=dict(
            argstr="-threshold_mask %s",
            extensions=None,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_norm_threshold_mask.mnc",
        ),
        threshold=dict(argstr="-threshold",),
        threshold_blur=dict(argstr="-threshold_blur %s",),
        threshold_bmt=dict(argstr="-threshold_bmt",),
        threshold_perc=dict(argstr="-threshold_perc %s",),
        upper=dict(argstr="-upper %s",),
    )
    inputs = Norm.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Norm_outputs():
    output_map = dict(
        output_file=dict(extensions=None,),
        output_threshold_mask=dict(extensions=None,),
    )
    outputs = Norm.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import XfmAvg


def test_XfmAvg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        avg_linear=dict(argstr="-avg_linear",),
        avg_nonlinear=dict(argstr="-avg_nonlinear",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        ignore_linear=dict(argstr="-ignore_linear",),
        ignore_nonlinear=dict(argstr="-ignore_nonline",),
        input_files=dict(argstr="%s", mandatory=True, position=-2, sep=" ",),
        input_grid_files=dict(),
        output_file=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        verbose=dict(argstr="-verbose",),
    )
    inputs = XfmAvg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_XfmAvg_outputs():
    output_map = dict(
        output_file=dict(extensions=None,), output_grid=dict(extensions=None,),
    )
    outputs = XfmAvg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Aparc2Aseg


def test_Aparc2Aseg_inputs():
    input_map = dict(
        a2009s=dict(argstr="--a2009s",),
        args=dict(argstr="%s",),
        aseg=dict(argstr="--aseg %s", extensions=None,),
        copy_inputs=dict(),
        ctxseg=dict(argstr="--ctxseg %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        filled=dict(extensions=None,),
        hypo_wm=dict(argstr="--hypo-as-wm",),
        label_wm=dict(argstr="--labelwm",),
        lh_annotation=dict(extensions=None, mandatory=True,),
        lh_pial=dict(extensions=None, mandatory=True,),
        lh_ribbon=dict(extensions=None, mandatory=True,),
        lh_white=dict(extensions=None, mandatory=True,),
        out_file=dict(argstr="--o %s", extensions=None, mandatory=True,),
        rh_annotation=dict(extensions=None, mandatory=True,),
        rh_pial=dict(extensions=None, mandatory=True,),
        rh_ribbon=dict(extensions=None, mandatory=True,),
        rh_white=dict(extensions=None, mandatory=True,),
        ribbon=dict(extensions=None, mandatory=True,),
        rip_unknown=dict(argstr="--rip-unknown",),
        subject_id=dict(argstr="--s %s", mandatory=True, usedefault=True,),
        subjects_dir=dict(),
        volmask=dict(argstr="--volmask",),
    )
    inputs = Aparc2Aseg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Aparc2Aseg_outputs():
    output_map = dict(out_file=dict(argstr="%s", extensions=None,),)
    outputs = Aparc2Aseg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import WarpPoints


def test_WarpPoints_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        coord_mm=dict(argstr="-mm", xor=["coord_vox"],),
        coord_vox=dict(argstr="-vox", xor=["coord_mm"],),
        dest_file=dict(argstr="-dest %s", extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_coords=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        out_file=dict(
            extensions=None,
            name_source="in_coords",
            name_template="%s_warped",
            output_name="out_file",
        ),
        src_file=dict(argstr="-src %s", extensions=None, mandatory=True,),
        warp_file=dict(argstr="-warp %s", extensions=None, xor=["xfm_file"],),
        xfm_file=dict(argstr="-xfm %s", extensions=None, xor=["warp_file"],),
    )
    inputs = WarpPoints.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_WarpPoints_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = WarpPoints.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import N4BiasFieldCorrection


def test_N4BiasFieldCorrection_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bias_image=dict(extensions=None, hash_files=False,),
        bspline_fitting_distance=dict(argstr="--bspline-fitting %s",),
        bspline_order=dict(requires=["bspline_fitting_distance"],),
        convergence_threshold=dict(requires=["n_iterations"],),
        copy_header=dict(mandatory=True, usedefault=True,),
        dimension=dict(argstr="-d %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        histogram_sharpening=dict(argstr="--histogram-sharpening [%g,%g,%d]",),
        input_image=dict(argstr="--input-image %s", extensions=None, mandatory=True,),
        mask_image=dict(argstr="--mask-image %s", extensions=None,),
        n_iterations=dict(argstr="--convergence %s",),
        num_threads=dict(nohash=True, usedefault=True,),
        output_image=dict(
            argstr="--output %s",
            hash_files=False,
            keep_extension=True,
            name_source=["input_image"],
            name_template="%s_corrected",
        ),
        rescale_intensities=dict(argstr="-r", min_ver="2.1.0", usedefault=True,),
        save_bias=dict(mandatory=True, usedefault=True, xor=["bias_image"],),
        shrink_factor=dict(argstr="--shrink-factor %d",),
        weight_image=dict(argstr="--weight-image %s", extensions=None,),
    )
    inputs = N4BiasFieldCorrection.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_N4BiasFieldCorrection_outputs():
    output_map = dict(
        bias_image=dict(extensions=None,), output_image=dict(extensions=None,),
    )
    outputs = N4BiasFieldCorrection.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsuite import Bfc


def test_Bfc_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        biasEstimateConvergenceThreshold=dict(argstr="--beps %f",),
        biasEstimateSpacing=dict(argstr="-s %d",),
        biasFieldEstimatesOutputPrefix=dict(argstr="--biasprefix %s",),
        biasRange=dict(argstr="%s",),
        controlPointSpacing=dict(argstr="-c %d",),
        convergenceThreshold=dict(argstr="--eps %f",),
        correctWholeVolume=dict(argstr="--extrapolate",),
        correctedImagesOutputPrefix=dict(argstr="--prefix %s",),
        correctionScheduleFile=dict(argstr="--schedule %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        histogramRadius=dict(argstr="-r %d",),
        histogramType=dict(argstr="%s",),
        inputMRIFile=dict(argstr="-i %s", extensions=None, mandatory=True,),
        inputMaskFile=dict(argstr="-m %s", extensions=None, hash_files=False,),
        intermediate_file_type=dict(argstr="%s",),
        iterativeMode=dict(argstr="--iterate",),
        maxBias=dict(argstr="-U %f", usedefault=True,),
        minBias=dict(argstr="-L %f", usedefault=True,),
        outputBiasField=dict(argstr="--bias %s", extensions=None, hash_files=False,),
        outputMRIVolume=dict(
            argstr="-o %s", extensions=None, genfile=True, hash_files=False,
        ),
        outputMaskedBiasField=dict(
            argstr="--maskedbias %s", extensions=None, hash_files=False,
        ),
        splineLambda=dict(argstr="-w %f",),
        timer=dict(argstr="--timer",),
        verbosityLevel=dict(argstr="-v %d",),
    )
    inputs = Bfc.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Bfc_outputs():
    output_map = dict(
        correctionScheduleFile=dict(extensions=None,),
        outputBiasField=dict(extensions=None,),
        outputMRIVolume=dict(extensions=None,),
        outputMaskedBiasField=dict(extensions=None,),
    )
    outputs = Bfc.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..denoising import DWIUnbiasedNonLocalMeansFilter


def test_DWIUnbiasedNonLocalMeansFilter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        hp=dict(argstr="--hp %f",),
        inputVolume=dict(argstr="%s", extensions=None, position=-2,),
        ng=dict(argstr="--ng %d",),
        outputVolume=dict(argstr="%s", hash_files=False, position=-1,),
        rc=dict(argstr="--rc %s", sep=",",),
        re=dict(argstr="--re %s", sep=",",),
        rs=dict(argstr="--rs %s", sep=",",),
    )
    inputs = DWIUnbiasedNonLocalMeansFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DWIUnbiasedNonLocalMeansFilter_outputs():
    output_map = dict(outputVolume=dict(extensions=None, position=-1,),)
    outputs = DWIUnbiasedNonLocalMeansFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import AvScale


def test_AvScale_inputs():
    input_map = dict(
        all_param=dict(argstr="--allparams",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        mat_file=dict(argstr="%s", extensions=None, position=-2,),
        ref_file=dict(argstr="%s", extensions=None, position=-1,),
    )
    inputs = AvScale.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AvScale_outputs():
    output_map = dict(
        average_scaling=dict(),
        backward_half_transform=dict(),
        determinant=dict(),
        forward_half_transform=dict(),
        left_right_orientation_preserved=dict(),
        rot_angles=dict(),
        rotation_translation_matrix=dict(),
        scales=dict(),
        skews=dict(),
        translations=dict(),
    )
    outputs = AvScale.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..regutils import RegResample


def test_RegResample_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        flo_file=dict(argstr="-flo %s", extensions=None, mandatory=True,),
        inter_val=dict(argstr="-inter %d",),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        out_file=dict(
            argstr="%s",
            extensions=None,
            name_source=["flo_file"],
            name_template="%s",
            position=-1,
        ),
        pad_val=dict(argstr="-pad %f",),
        psf_alg=dict(argstr="-psf_alg %d",),
        psf_flag=dict(argstr="-psf",),
        ref_file=dict(argstr="-ref %s", extensions=None, mandatory=True,),
        tensor_flag=dict(argstr="-tensor ",),
        trans_file=dict(argstr="-trans %s", extensions=None,),
        type=dict(argstr="-%s", position=-2, usedefault=True,),
        verbosity_off_flag=dict(argstr="-voff",),
    )
    inputs = RegResample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegResample_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = RegResample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTITracker


def test_DTITracker_inputs():
    input_map = dict(
        angle_threshold=dict(argstr="-at %f",),
        angle_threshold_weight=dict(argstr="-atw %f",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        input_data_prefix=dict(argstr="%s", position=0, usedefault=True,),
        input_type=dict(argstr="-it %s",),
        invert_x=dict(argstr="-ix",),
        invert_y=dict(argstr="-iy",),
        invert_z=dict(argstr="-iz",),
        mask1_file=dict(argstr="-m %s", extensions=None, mandatory=True, position=2,),
        mask1_threshold=dict(position=3,),
        mask2_file=dict(argstr="-m2 %s", extensions=None, position=4,),
        mask2_threshold=dict(position=5,),
        output_file=dict(argstr="%s", extensions=None, position=1, usedefault=True,),
        output_mask=dict(argstr="-om %s", extensions=None,),
        primary_vector=dict(argstr="-%s",),
        random_seed=dict(argstr="-rseed %d",),
        step_length=dict(argstr="-l %f",),
        swap_xy=dict(argstr="-sxy",),
        swap_yz=dict(argstr="-syz",),
        swap_zx=dict(argstr="-szx",),
        tensor_file=dict(extensions=None,),
        tracking_method=dict(argstr="-%s",),
    )
    inputs = DTITracker.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTITracker_outputs():
    output_map = dict(
        mask_file=dict(extensions=None,), track_file=dict(extensions=None,),
    )
    outputs = DTITracker.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..connectivity import BuildConnectome


def test_BuildConnectome_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        in_parc=dict(argstr="%s", extensions=None, position=-2,),
        in_scalar=dict(argstr="-image %s", extensions=None,),
        in_weights=dict(argstr="-tck_weights_in %s", extensions=None,),
        keep_unassigned=dict(argstr="-keep_unassigned",),
        metric=dict(argstr="-metric %s",),
        nthreads=dict(argstr="-nthreads %d", nohash=True,),
        out_file=dict(
            argstr="%s", extensions=None, mandatory=True, position=-1, usedefault=True,
        ),
        search_forward=dict(argstr="-assignment_forward_search %f",),
        search_radius=dict(argstr="-assignment_radial_search %f",),
        search_reverse=dict(argstr="-assignment_reverse_search %f",),
        vox_lookup=dict(argstr="-assignment_voxel_lookup",),
        zero_diagonal=dict(argstr="-zero_diagonal",),
    )
    inputs = BuildConnectome.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BuildConnectome_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = BuildConnectome.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dcm2nii import Dcm2niix


def test_Dcm2niix_inputs():
    input_map = dict(
        anon_bids=dict(argstr="-ba", requires=["bids_format"],),
        args=dict(argstr="%s",),
        bids_format=dict(argstr="-b", usedefault=True,),
        comment=dict(argstr="-c %s",),
        compress=dict(argstr="-z %s", usedefault=True,),
        compression=dict(argstr="-%d",),
        crop=dict(argstr="-x", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        has_private=dict(argstr="-t", usedefault=True,),
        ignore_deriv=dict(argstr="-i",),
        merge_imgs=dict(argstr="-m", usedefault=True,),
        out_filename=dict(argstr="-f %s",),
        output_dir=dict(argstr="-o %s", usedefault=True,),
        philips_float=dict(argstr="-p",),
        series_numbers=dict(argstr="-n %s...",),
        single_file=dict(argstr="-s", usedefault=True,),
        source_dir=dict(
            argstr="%s", mandatory=True, position=-1, xor=["source_names"],
        ),
        source_names=dict(
            argstr="%s",
            copyfile=False,
            mandatory=True,
            position=-1,
            xor=["source_dir"],
        ),
        to_nrrd=dict(argstr="-e",),
        verbose=dict(argstr="-v", usedefault=True,),
    )
    inputs = Dcm2niix.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Dcm2niix_outputs():
    output_map = dict(bids=dict(), bvals=dict(), bvecs=dict(), converted_files=dict(),)
    outputs = Dcm2niix.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
